# -*- coding: utf-8 -*-
from setuphelpers import *

def update_package():
    print("Downloading/Updating package content from upstream binary sources")

    # Initializing variables
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()

    bin_name_string = "cudatext-win-x32-%s.zip"
    app_name = control.name
    url = control.sources

    # Getting latest version from official website
    print("URL used is: " + url)
    url_dl = get_download_url_from_fosshub(url, file_type="win x32", proxies=proxies)
    version = bs_find(url, "dd", "itemprop", "softwareVersion", proxies=proxies).text
    latest_bin = bin_name_string % version

    print("Latest %s version is: %s" % (app_name, version))
    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(url_dl, latest_bin, proxies=proxies)

        # Changing version of the package
        control.version = "%s-%s" % (version, int(control.version.split("-")[-1]) + 1)
        control.save_control_to_wapt()
        print("Changing version to: %s in WAPT\\control" % control.version)

    # Deleting outdated binaries
    remove_outdated_binaries(version, list_extensions=bin_name_string.split("."[-1]))


def get_download_url_from_fosshub(url, file_type="64-bit Windows Installer", proxies=None):
    import json
    import requests

    url_api_fosshub = "https://university.fosshub.com/projects.json"

    for script in bs_find_all(url, "script", proxies=proxies):
        if (len(script.contents) >= 1) and ("var settings" in script.contents[0]):
            var_settings = script.contents[0].replace("\n  var settings =", "").replace("\n", "")
            break

    for readapifosshub in json.loads(wgets(url_api_fosshub, proxies=proxies))["projects"]:
        if readapifosshub["url"].endswith(url.split("//")[-1]):
            for filename in readapifosshub["files"]:
                if filename["type"] == file_type:
                    file_name = filename["name"]

    settings = json.loads(var_settings)

    apiUrl = "https://api." + settings["domain"]
    downloadUrl = apiUrl + "/download/"

    def forming_fosshub_url(a, b, c, d, e):
        params = {"projectId": a, "releaseId": b, "projectUri": c, "fileName": d, "source": e}
        r = requests.post(downloadUrl, data=params, proxies=proxies)
        return r

    pool = settings["pool"]
    f = pool["f"]

    for c in f:
        r = forming_fosshub_url(pool["p"], c["r"], pool["u"], file_name, pool["c"])

    r = forming_fosshub_url(pool["p"], c["r"], pool["u"], file_name, pool["c"])
    rj = r.json()
    return rj["data"]["url"]